<?php

/* 
 * Copyright (C) 2014 NoccyLabs.info
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace NoccyLabs\BootstrapBundle\Twig;

/**
 * Twig extension for Page2Images
 */
class BootstrapExtension extends \Twig_Extension
{

    public function getFilters()
    {
        return array(
            new \Twig_SimpleFilter('stars', array($this, 'starFilter'), array('is_safe' => array('html'))),
        );
    }
    
    public function getFunctions()
    {
        return array(
            new \Twig_SimpleFunction('icon', array($this, 'iconFunction'), array('is_safe' => array('html'))),
            new \Twig_SimpleFunction('breadcrumbs', array($this, 'breadcrumbsFunction'), array('is_safe' => array('html'))),
        );
    }

    public function starFilter($value, $max=5, $fill_color='gold', $empty_color='gray')
    {
        $out = null;
        for($n = 1; $n <= (int)$max; $n++) {
            $color = urlencode(((int)$value>=$n)?$fill_color:$empty_color);
            $out.= "<span class=\"glyphicon glyphicon-star\" style=\"color:".$color.";\"></span>";
        }
        return $out;
    }
    
    public function iconFunction($classes)
    {
        // if we only get the class, such as 'glyphicon-ok', we can assume the correct class
        // should be 'glyphicon glyphicon-ok'. So, check for a space and in its absence try
        // to autocomplete the class.
        if (strpos($classes," ")===false) {
                if (strpos($classes,"-")!==false) {
                    // Grab the head, i.e. prefix
                    $prefixes = explode("-", $classes);
                    $prefix = reset($prefixes);
                    $classes = $prefix.' '.$classes;
                }
        }
        return '<span class="'.$classes.'"></span>';
    }

    public function breadcrumbsFunction($crumbs)
    {
        $path = array();
        foreach ($crumbs as $crumb) {
            if (is_array($crumb)) {
                $c = (object)$crumb;
                if (isset($c->active) && ($c->active)) {
                    $cr = "<li class=\"active\">%s</li>";
                } else {
                    $cr = "<li>%s</li>";
                }
                if (isset($c->href)) {
                    $cr = sprintf($cr, "<a href=\"%s\">%%s</a>");
                    $cr = sprintf($cr, $c->href);
                } else {
                    $crumb_href = "#";
                }
                if (isset($c->label)) {
                    $cr = sprintf($cr, $c->label);
                } else {
                    $cr = sprintf($cr, "No label");
                }
                $path[] = $cr;
            } else {
                $path[] = "<li>" . $crumb . "</li>";
            }
        }

        $html = sprintf(
            "<ol class=\"breadcrumb\">%s</ol>",
            join("", $path)
        );
        return $html;
    }

    /**
     *
     * @return string The extension name
     */
    public function getName()
    {
        return 'noccylabsbootstrap_extension';
    }
    
}
